% INJ
% LaTeX class file for papers submitted for publication in the
% Bollettino dell'Accademia Gioenia di Scienze Naturali (Catania)
% (c) 2019 G. G. N. Angilella <giuseppe.angilella@ct.infn.it>
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{gioenia}[2019/05/13 Boll. Accad. Gioenia Sci. Nat. (Catania)]

%\newcommand\Authfont{\normalfont}
%\newcommand\Affilfont{\normalfont}
%\newcommand\Authsep{, }
%\newcommand\Authands{, and }
%\newcommand\Authand{ and }


\DeclareOption{italian}{%\renewcommand\Authand{, e }%
                        %\renewcommand\Authands{, e }%
                        \AtBeginDocument{\selectlanguage{italian}}
                        \def\@mainlanguage{italian}
                        \def\@otherlanguage{english}}
\DeclareOption{english}{\AtBeginDocument{\selectlanguage{english}}
                        \def\@mainlanguage{english}
                        \def\@otherlanguage{italian}}


\newcommand{\papertype}[1]{\def\@papertype{#1}}

\DeclareOption{invited}{\papertype{IP}} % Invited Paper
\DeclareOption{full}{\papertype{FP}} % Full Paper
\DeclareOption{opening}{\papertype{OL}} % Opening Lecture
\DeclareOption{obituary}{\papertype{OB}} % Obituary
\DeclareOption{misc}{\papertype{MISC}} % Miscellanea
\DeclareOption{focus}{\papertype{SFE}} % Special Focus Edition

\ProcessOptions\relax


\newcommand{\volume}[1]{\def\@vol{#1}}
\newcommand{\numb}[1]{\def\@numb{#1}}
\newcommand{\firstpage}[1]{\def\@firstpage{#1}}
\newcommand{\lastpage}[1]{\def\@lastpage{#1}}
\newcommand{\articleno}[1]{\def\@articleno{#1}}
\newcommand{\pubyear}[1]{\def\@pubyear{#1}}

\newcommand{\summary}[1]{\def\@summary{#1}}
\newcommand{\keywords}[1]{\def\@keywords{#1}}
\newcommand{\riassunto}[1]{\def\@riassunto{#1}}
\newcommand{\parolechiave}[1]{\def\@parolechiave{#1}}

\volume{vvv}
\numb{nnn}
\firstpage{1}
\lastpage{\pageref{LastPage}}
\articleno{xx}
\pubyear{\the\year}


\LoadClass[12pt,twoside]{article}
\RequirePackage[a-1b]{pdfx}
\RequirePackage[text={15truecm,24truecm},centering,includehead,includefoot]{geometry}
\RequirePackage{graphicx}
\RequirePackage{color}
\RequirePackage{tikz} % For Orcid icon
\RequirePackage{xargs} % For \author with multiple optional arguments
\RequirePackage{doi}
\hypersetup{%
   colorlinks=true,
   allcolors=blue
}
%\RequirePackage{filecontents} % To enable generation of metadata for the PDF/A file
\RequirePackage{hyperxmp} % To enable generation of metadata for the PDF/A file

\RequirePackage{fancyhdr}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
%\fancyhead[LE,RO]{{\slshape \leftmark}\break{\slshape \rightmark}}
%\fancyfoot[C]{\thepage}

\RequirePackage{lastpage}
\RequirePackage[utf8]{inputenc}
\RequirePackage[italian,english]{babel}
\RequirePackage[sc]{mathpazo}
\linespread{1.05}         % Palladio needs more leading (space between lines)
\RequirePackage{natbib}
%\newcommand{\bibfont}{\small}
\setlength{\bibsep}{0pt}

%\RequirePackage{authblk}



\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                       {3.25ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\normalfont\normalsize\bfseries}}




%\newcommand{\email}[1]{\renewcommand{\thefootnote}{\fnsymbol{footnote}}\footnote[1]{E-mail: #1}\setcounter{footnote}{0}\renewcommand{\thefootnote}{\arabic{footnote}}}
\newcommand{\email}[1]{\footnote{E-mail: #1}}


%% ORCID
% Make Orcid icon
\definecolor{lime}{HTML}{A6CE39}
\newcommand{\orcidicon}{%
	\begin{tikzpicture}
	\draw[lime, fill=lime] (0,0) 
		circle [radius=0.16] 
		node[white] {{\fontfamily{qag}\selectfont \tiny ID}};
	\draw[white, fill=white] (-0.078,0.1) % (-0.0625,0.095) 
		circle [radius=0.007];
	\end{tikzpicture}
	\hspace{-2mm}
}


\newif\iffirstauthor
\firstauthortrue

\newcounter{authorsno}
\newcounter{runningauthorsmax}
\setcounter{runningauthorsmax}{3}

\def\@runningauthors{}
\def\@fullauthorslist{}
\def\@firstrunningauthor{}

%\renewcommand{\author}[4][]{%
\renewcommandx{\author}[4][1,2]{%
   \stepcounter{authorsno}
   \iffirstauthor
      \ifthenelse { \equal {#1} {} }
         {\def\@author{#4$^{#3}$%
                       \ifthenelse{ \equal {#2} {} }{}{\expandafter\href{https://orcid.org/#2}{\expandafter\orcidicon}}%
         }}
         {\def\@author{#4$^{#3}$%
                       \email{#1}%
                       \ifthenelse{ \equal {#2} {} }{}{\expandafter\href{https://orcid.org/#2}{\expandafter\orcidicon}}%
         }}
      \firstauthorfalse
      \def\@runningauthors{#4}
      \def\@firstrunningauthor{#4}
      \def\@fullauthorslist{#4}
   \else
      \ifthenelse { \equal {#1} {} }
         {\g@addto@macro\@author{, #4$^{#3}$%
                       \ifthenelse{ \equal {#2} {} }{}{\expandafter\href{https://orcid.org/#2}{\expandafter\orcidicon}}%
         }}
         {\g@addto@macro\@author{, #4$^{#3}$%
                       \email{#1}%
                       \ifthenelse{ \equal {#2} {} }{}{\expandafter\href{https://orcid.org/#2}{\expandafter\orcidicon}}%
         }}
      \ifthenelse { \theauthorsno < \therunningauthorsmax }
         {\g@addto@macro\@runningauthors{, #4}}
         {}
      \ifthenelse { \theauthorsno = \therunningauthorsmax }
         {\g@addto@macro\@runningauthors{, #4}}
         {}
      \ifthenelse { \theauthorsno > \therunningauthorsmax }
         {\def\@runningauthors{\@firstrunningauthor{} et al.}}
         {}
      \g@addto@macro\@fullauthorslist{, #4}
   \fi
}

\newif\iffirstaffil
\firstaffiltrue

\newcommand{\affil}[2]{%
   \iffirstaffil
      \def\@affil{$^{#1}$#2}
      \firstaffilfalse
   \else
      \g@addto@macro\@affil{\\ $^{#1}$#2}
   \fi
}

\renewcommand\title[3][]{%
   \ifthenelse{\equal{#2}{english}}
      {\def\@title{#3}
       \ifthenelse{\equal{#1}{}}
          {\def\@abridgedtitle{#3}}
          {\def\@abridgedtitle{#1}}
      }
      {\def\@titolo{#3}
       \ifthenelse{\equal{#1}{}}
          {\def\@abridgedtitolo{#3}}
          {\def\@abridgedtitolo{#1}}
      }
}



\summary{}
\ifthenelse{\equal{\@summary}{}}{\summary{EMPTY SUMMARY. Please, provide an English summary for the paper, with \texttt{\textbackslash{}summary\{Text of the summary.\}}.}}{}
\keywords{}
\ifthenelse{\equal{\@keywords}{}}{\keywords{NO KEYWORDS. Please, provide keywords in English, with \texttt{\textbackslash{}keywords\{key1, key2, key3.\}}.}}{}
\riassunto{}
\ifthenelse{\equal{\@riassunto}{}}{\riassunto{NESSUN RIASSUNTO. Si prega di includere un riassunto in Italiano, usando il comando \texttt{\textbackslash{}riassunto\{Testo del riassunto.\}}.}}{}
\parolechiave{}
\ifthenelse{\equal{\@parolechiave}{}}{\parolechiave{NESSUNA PAROLA CHIAVE. Si prega di includere alcune parole chiave in Italiano, usando il comando \texttt{\textbackslash{}parolechiave\{parola chiave1, parola chiave2, parola chiave3.\}}.}}{}

\title{english}{}
\ifthenelse{\equal{\@title}{}}{\title{english}{NO ENGLISH TITLE.\\ Please, provide a title in English, with \texttt{\textbackslash{}title[Abridged title for running heads]\{english\}\{Complete title for headline\}}.}}{}
\title{italian}{}
\ifthenelse{\equal{\@titolo}{}}{\title{italian}{NESSUN TITOLO.\\ Si prega di includere un titolo in Italiano, usando il comando \texttt{\textbackslash{}title[Titolo abbreviato per l'intestazione]\{italian\}\{Titolo completo dell'articolo\}}.}}{}



%\renewcommand{\maketitle}{%
\def\maketitle{%
%  \renewenvironment{tabular}[2][]{\begin{center}}
%                                   {\end{center}}
   \noindent%
   \begin{minipage}[t][1.5truecm][t]{0.44\textwidth}
      \begin{flushleft}
         \begin{scriptsize}
            \color{blue}{\bf Accademia Gioenia di Scienze Naturali (Catania)}\\%
            \color{blue}{\emph{Anno di fondazione 1824}}\\%
         \end{scriptsize}
      \end{flushleft}
   \end{minipage}
   \begin{minipage}[t][1.5truecm][c]{0.12\textwidth}
      \vspace{-1.5em}
      \includegraphics[width=\textwidth]{logo_gioenia.jpg}
   \end{minipage}
   \begin{minipage}[t][1.5truecm][t]{0.44\textwidth}
      \begin{flushright}
         \begin{scriptsize}
            \color{blue}{%
               Boll. Accad. Gioenia Sci. Nat. (Catania)\\%
               {\bf \@vol{}} (\@numb{}), {\@papertype{}\@firstpage{}}--{\@papertype{}\@lastpage{}} (\@pubyear{})\\%
%               \hfill doi:\href{https://doi.org/10.35352/v\@vol i\@numb .\@articleno}{10.35352/v\@vol{}i\@numb{}.\@articleno{}}\\%
               \hfill \doi{10.35352/v\@vol i\@numb .\@articleno}\\%
            }
         \end{scriptsize}
      \end{flushright}
   \end{minipage}
   \vspace{1.5truecm}
   \renewcommand{\thefootnote}{\fnsymbol{footnote}}
   \setcounter{footnote}{0}
   \begin{center}
      \iflanguage{english}{\large\bf\@title}{}
      \iflanguage{italian}{\large\bf\@titolo}{}
   \end{center}
%   \renewcommand{\thefootnote}{\arabic{footnote}}
%   \setcounter{footnote}{0}
   \medskip
   \begin{center}
%      \renewcommand{\thefootnote}{\fnsymbol{footnote}}
%      \setcounter{footnote}{0}
      \@author
      \setcounter{footnote}{0}
      \renewcommand{\thefootnote}{\arabic{footnote}}
   \end{center}
   \medskip
   \begin{center}
      \begin{itshape}
         \@affil
      \end{itshape}
   \end{center}
   \medskip
%
   \ifthenelse{\equal{\@mainlanguage}{english}}{%
%
      \begin{center}
         {\bf Summary}
      \end{center}
      \medskip
      {\begin{otherlanguage}{english}\begin{small}\noindent\@summary\\[.5\baselineskip]\noindent{\bf Keywords:} {\itshape \@keywords}\end{small}\end{otherlanguage}}
      \newline\medskip
      \noindent\begin{minipage}{\textwidth}
         \begin{center}
            {\bf Riassunto}\\[.5\baselineskip]
            {\itshape\bfseries\@titolo}
         \end{center}
         \medskip
         \begin{otherlanguage}{italian}\begin{small}\noindent\@riassunto\\[.5\baselineskip]\noindent{\bf Parole chiave:} {\itshape \@parolechiave}\end{small}\end{otherlanguage}
      \end{minipage}
%
   }{%
%
      \begin{center}
         {\bf Riassunto}
      \end{center}
      \medskip
      {\begin{otherlanguage}{italian}\begin{small}\noindent\@riassunto\\[.5\baselineskip]\noindent{\bf Parole chiave:} {\itshape \@parolechiave}\end{small}\end{otherlanguage}}
      \newline\medskip
      \noindent\begin{minipage}{\textwidth}
         \begin{center}
            {\bf Summary}\\[.5\baselineskip]
            {\itshape\bfseries\@title}
         \end{center}
         \medskip
         \begin{otherlanguage}{english}\begin{small}\noindent\@summary\\[.5\baselineskip]\noindent{\bf Keywords:} {\itshape \@keywords}\end{small}\end{otherlanguage}
      \end{minipage}
%
   }
%
   \medskip
   \setcounter{footnote}{0}
   \renewcommand{\thefootnote}{\arabic{footnote}}
   \hypersetup{% metadata for the pdf/a file
      pdftitle = \@title,
      pdfauthor = \@fullauthorslist,
      pdfsubject = \@summary,
      pdfkeywords = \@keywords
%      ,pdfdoi = 10.35352/v\@vol i\@numb .\@articleno
   }
}

\ifthenelse{\equal{\@mainlanguage}{english}}{\AtBeginDocument{\selectlanguage{english}}}{}
\ifthenelse{\equal{\@mainlanguage}{italian}}{\AtBeginDocument{\selectlanguage{italian}}}{}

%\iflanguage{english}{\AtBeginDocument{\selectlanguage{english}}}{}
%\iflanguage{italian}{\AtBeginDocument{\selectlanguage{italian}}}{}

%\def\leftmark{\@papertype\thepage\hfill Autori}
%\def\rightmark{\@abridgedtitle\hfill\@papertype\thepage}
%\fancyhead[LE,RO]{{\slshape \leftmark}\break{\slshape \rightmark}}
\fancyhead{}
\fancyfoot{}
%\fancyhead[LE,RO]{{\slshape \leftmark}}
%\fancyhead[RO,LE]{{\slshape \rightmark}}
%\fancyhead[LE,RO]{{\slshape \@papertype\thepage\hfill Autori}}
%\fancyhead[RO,LE]{{\slshape \@abridgedtitle\hfill\@papertype\thepage}}
%\fancyfoot[C]{\thepage}
\fancyhead[RO]{\@papertype\thepage}
\fancyhead[LE]{\@papertype\thepage}
\ifthenelse{\equal{\@mainlanguage}{english}}{\fancyhead[RE]{{\itshape\@abridgedtitle}}}{}
\ifthenelse{\equal{\@mainlanguage}{italian}}{\fancyhead[RE]{{\itshape\@abridgedtitolo}}}{}
\fancyhead[LO]{\@runningauthors}

\pagestyle{fancy}
\thispagestyle{empty}



